@@ -24,11 +24,14 @@ def reconstitute_signal_perf(data=None, initial_price = 1. , average_execution_c
     data['reconstituted_perf'] = metrics.from_ret_to_price(data['perf_return'],initial_price=initial_price)
     return data
 
-def roll_wrapper(rolled_df, lookback_window, skipping_size, function_to_apply):
+def roll_wrapper(rolled_df, lookback_window, skipping_size, function_to_apply, trigger):
     signal_df = roll(rolled_df, lookback_window).apply(function_to_apply)
     signal_df = signal_df.to_frame()
     signal_df.columns = ['signal_gen']
     signal_df['signal'] = signal_df['signal_gen'].shift()
+    if trigger:
+        signal_df['signal'] =  signal_df['signal'].fillna(method='ffill')
+        signal_df = signal_df.fillna(0.)
     rolled_df = pd.merge(rolled_df, signal_df, how='left', left_index=True, right_index= True)
     rolled_df = rolled_df.iloc[skipping_size:]
     return rolled_df
@@ -57,14 +60,14 @@ class AbstractRunner(ABC):
         self.starting_date = starting_date
 
     @abstractmethod
-    def runTrial(self,saver, seed, signal_type, look_back_window, threshold, contravariant, idios):
+    def runTrial(self,saver, seed, trigger, signal_type, look_back_window, threshold, contravariant, idios):
         pass
 
 
 class SimpleSignalRunner(AbstractRunner):
-    def runTrial(self, saver, seed, signal_type, idios_string):
+    def runTrial(self, saver, seed, trigger, signal_type, idios_string):
         idios = json.loads(idios_string)
-        meArg = (seed,  signal_type,  idios_string)
+        meArg = (seed,  trigger, signal_type,  idios_string)
         meArgList = list(meArg)
         meArgList = [str(it) for it in meArgList]
         savingKey = ''.join(meArgList)
@@ -87,7 +90,9 @@ class SimpleSignalRunner(AbstractRunner):
         signal_generation_method_to_call = getattr(signal_generator, signal_type)
         hourly_df = pd.read_pickle(self.local_root_directory+self.hourly_pkl_file_name)
         hourly_df = roll_wrapper(hourly_df, lookback_window, skipping_size,
-                                  lambda x: signal_generation_method_to_call(data=x, **idios))
+                                  lambda x: signal_generation_method_to_call(data=x, **idios), trigger)
+
+
         hourly_df = reconstitute_signal_perf(hourly_df)
         sharpe_strat = metrics.sharpe(hourly_df['perf_return'].dropna(), period= 252 * 24, from_ret=True)
         sharpe_under = metrics.sharpe(hourly_df['close_return'].dropna(), period= 252 * 24, from_ret=True)
