@@ -15,8 +15,6 @@ def generate_lead_lag(lookback_windows, contravariants):
                 })
     return parameters
 
-
-
 def generate_dd_threshold(lookback_windows, thresholds, contravariants):
     parameters = []
     for lookback_window in lookback_windows:
@@ -28,3 +26,17 @@ def generate_dd_threshold(lookback_windows, thresholds, contravariants):
                     'threshold':threshold
                 })
     return parameters
+
+def generate_volume_weighted_high_low_vol(lookback_windows, vol_thresholds, trend_thresholds, contravariants):
+    parameters = []
+    for lookback_window in lookback_windows:
+        for contravariant in contravariants:
+            for vol_threshold in vol_thresholds:
+                for trend_threshold in trend_thresholds:
+                    parameters.append({
+                        'lookback_window':lookback_window,
+                        'contravariant':contravariant,
+                        'vol_threshold':vol_threshold,
+                        'trend_threshold':trend_threshold
+                    })
+    return parameters
\ No newline at end of file
