@@ -2,6 +2,7 @@
 # coding: utf-8
 
 import talib
+import numpy as np
 
 def dd_threshold(data = None, threshold=1., contravariant = -1, **kwargs):
     ratio = data['high'][-1]/data['high'][0]
@@ -18,13 +19,17 @@ def lead_lag_indicator(data = None, lead=3, lag=5, contravariant = -1, **kwargs)
     else :
         return contravariant
 
-def volume_weighted_high_low_vol(data = None , threshold = 0.01):
+def volume_weighted_high_low_vol(data = None , vol_threshold = 0.005, trend_threshold=0.005, contravariant = 1., **kwargs):
+    trend = (data['close'][-1]/data['close'][0])/data['close'][0]
     data['hl'] = (data['high'] - data['low'])/data['low']
-    data['volu_hi_low'] = data['volume']*(data['high'] - data['low'])
-    volu_hi_low = data['volu_hi_low'].sum()
-    if volu_hi_low > threshold:
-        return 1
-    elif volu_hi_low < -threshold:
-        return -1
+    data['volu_hi_low'] = data['volumefrom']*data['hl']
+    weighted_volu_hi_low = data['volu_hi_low'].sum() / data['volumefrom'].sum()
+    if weighted_volu_hi_low > vol_threshold:
+        if trend > trend_threshold:
+            return contravariant
+        elif trend < -trend_threshold:
+            return -contravariant
+        else:
+            return np.nan
     else :
-        return 0
\ No newline at end of file
+        return np.nan
\ No newline at end of file
